@@ -3,6 +3,6 @@
 ###################
 # Scripts made by Eric #
 
-from gooblerpkg.Core.init import Init
+from ..Core.init import Init
 
 Init()
\ No newline at end of file
